conrey_dirichlet_characters: Dirichlet characters using a numbering scheme described by Brian Conrey
====================================================================================================

Description
-----------

Cython code for working with Dirichlet characters
using a numbering scheme described by Brian Conrey.


License
-------

None


Upstream Contact
----------------

- https://github.com/jwbober/conrey-dirichlet-characters
- https://github.com/passagemath/passagemath-pkg-conrey-dirichlet-characters
